@@ -31,8 +31,6 @@ from splitit_client.model.initiate_plan_response import InitiatePlanResponse
 from splitit_client.model.initiate_plan_response_extended_params import InitiatePlanResponseExtendedParams
 from splitit_client.model.initiate_redirection_endpoints_model import InitiateRedirectionEndpointsModel
 from splitit_client.model.installment import Installment
-from splitit_client.model.installment_plan_cancel_request import InstallmentPlanCancelRequest
-from splitit_client.model.installment_plan_cancel_response import InstallmentPlanCancelResponse
 from splitit_client.model.installment_plan_create_request import InstallmentPlanCreateRequest
 from splitit_client.model.installment_plan_create_response import InstallmentPlanCreateResponse
 from splitit_client.model.installment_plan_create_response_extended_params import InstallmentPlanCreateResponseExtendedParams
